<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi_FI">
<context>
    <name>AddChannelsDialog</name>
    <message>
        <location filename="addchannelsdialog.ui" line="33"/>
        <source>Fixture Mode Channels Editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="addchannelsdialog.ui" line="114"/>
        <source>Available channels</source>
        <oldsource>All channels</oldsource>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="addchannelsdialog.ui" line="106"/>
        <location filename="addchannelsdialog.ui" line="135"/>
        <source>Name</source>
        <translation type="unfinished">Nimi</translation>
    </message>
    <message>
        <location filename="addchannelsdialog.ui" line="121"/>
        <source>Mode channels</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>App</name>
    <message>
        <location filename="app.cpp" line="122"/>
        <source>Unrecognized file extension: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="app.cpp" line="150"/>
        <source>Fixture loading failed</source>
        <translation>Valaisimen lataus epäonnistui</translation>
    </message>
    <message>
        <location filename="app.cpp" line="151"/>
        <source>Unable to load fixture definition: </source>
        <translation>Valaisinmäärittelyä ei löydy: </translation>
    </message>
    <message>
        <location filename="app.cpp" line="245"/>
        <source>&amp;New</source>
        <translation>&amp;Uusi</translation>
    </message>
    <message>
        <location filename="app.cpp" line="246"/>
        <source>CTRL+N</source>
        <comment>File|New</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="app.cpp" line="251"/>
        <source>&amp;Open</source>
        <translation>A&amp;vaa</translation>
    </message>
    <message>
        <location filename="app.cpp" line="252"/>
        <source>CTRL+O</source>
        <comment>File|Open</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="app.cpp" line="257"/>
        <source>&amp;Save</source>
        <translation>&amp;Tallenna</translation>
    </message>
    <message>
        <location filename="app.cpp" line="258"/>
        <source>CTRL+S</source>
        <comment>File|Save</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="app.cpp" line="263"/>
        <source>Save &amp;As...</source>
        <translation>Tallenna nimellä...</translation>
    </message>
    <message>
        <location filename="app.cpp" line="264"/>
        <source>CTRL+SHIFT+S</source>
        <comment>File|Save As...</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="app.cpp" line="269"/>
        <source>&amp;Quit</source>
        <translation>&amp;Poistu</translation>
    </message>
    <message>
        <location filename="app.cpp" line="270"/>
        <source>CTRL+Q</source>
        <comment>File|Quit</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="app.cpp" line="276"/>
        <source>Index</source>
        <translation>Hakemisto</translation>
    </message>
    <message>
        <location filename="app.cpp" line="277"/>
        <source>SHIFT+F1</source>
        <comment>Help|Index</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="app.cpp" line="282"/>
        <source>About Fixture Definition Editor...</source>
        <translation>Tietoja Fixture Definition Editor-sovelluksesta...</translation>
    </message>
    <message>
        <location filename="app.cpp" line="287"/>
        <source>About Qt...</source>
        <translation>Tietoja Qt:sta...</translation>
    </message>
    <message>
        <location filename="app.cpp" line="314"/>
        <source>&amp;File</source>
        <translation>&amp;Tiedosto</translation>
    </message>
    <message>
        <location filename="app.cpp" line="324"/>
        <source>&amp;Help</source>
        <translation>&amp;Apua</translation>
    </message>
    <message>
        <location filename="app.cpp" line="362"/>
        <source>Open a fixture definition</source>
        <translation>Avaa valaisinmäärittely</translation>
    </message>
</context>
<context>
    <name>CapabilityWizard</name>
    <message>
        <location filename="capabilitywizard.ui" line="33"/>
        <source>Capability Wizard</source>
        <translation>Toimintovelho</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="39"/>
        <source>Values</source>
        <translation>Arvot</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="45"/>
        <source>Start</source>
        <translation>Aloitus</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="52"/>
        <source>The starting DMX value</source>
        <translation>Ensimmäinen DMX-arvo</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="62"/>
        <source>Width</source>
        <translation type="unfinished">Leveys</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="69"/>
        <source>Number of values per capability</source>
        <translation>Arvojen määrä toimintoa kohden</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="85"/>
        <source>Amount</source>
        <translation>Määrä</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="92"/>
        <source>Number of capabilities to create</source>
        <translation>Luotavien toimintojen määrä</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="108"/>
        <source>Name</source>
        <translation>Nimi</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="114"/>
        <source>The common base name for all capabilities. Use hash &apos;#&apos; to create a running number.</source>
        <translation>Yhteinen perusnimi kaikille toiminnoille. Käytä risuaitamerkkiä &apos;#&apos; juoksevaan numerointiin.</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="117"/>
        <source>Capability #</source>
        <translation>Toiminto #</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="127"/>
        <source>Sample</source>
        <translation>Esimerkki</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="133"/>
        <source>A list of capabilities that would be created with these settings</source>
        <translation>Lista toiminnoista, jotka voidaan luoda nykyisillä asetuksilla</translation>
    </message>
</context>
<context>
    <name>EditChannel</name>
    <message>
        <location filename="editchannel.ui" line="33"/>
        <source>Edit Channel</source>
        <translation>Muokkaa kanavaa</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="114"/>
        <source>&lt;font color=&quot;red&quot;&gt;&lt;b&gt;Capability overlapping detected. Please fix.&lt;/b&gt;&lt;/font&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="198"/>
        <source>Name</source>
        <translation>Nimi</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="240"/>
        <source>Default value</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="253"/>
        <source>Type</source>
        <translation type="unfinished">Tyyppi</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="260"/>
        <location filename="editchannel.ui" line="303"/>
        <source>Preset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="267"/>
        <source>The name of this channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="274"/>
        <source>Role</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="336"/>
        <source>Color 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="360"/>
        <source>Color 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="387"/>
        <source>Value 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="401"/>
        <source>Value 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="430"/>
        <source>Preview</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="227"/>
        <source>The group this channel belongs to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="322"/>
        <source>Picture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="283"/>
        <source>Coarse (MSB)</source>
        <translation>Karkea (MSB)</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="290"/>
        <source>Fine (LSB)</source>
        <translation>Hieno (LSB)</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="55"/>
        <source>Capabilities</source>
        <translation>Toiminnot</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="90"/>
        <location filename="editchannel.cpp" line="571"/>
        <source>Minimum value</source>
        <translation>Pienin arvo</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="95"/>
        <location filename="editchannel.cpp" line="571"/>
        <source>Maximum value</source>
        <translation>Suurin arvo</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="100"/>
        <location filename="editchannel.cpp" line="571"/>
        <source>Description</source>
        <translation>Kuvaus</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="154"/>
        <source>Remove the selected capability</source>
        <translation>Poista valittu valmius</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="121"/>
        <source>Capability wizard</source>
        <translation>Toimintovelho</translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="92"/>
        <source>Edit Channel: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="480"/>
        <source>Overlapping values</source>
        <translation>Päällekkäisiä arvoja</translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="497"/>
        <source>Open Gobo File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="500"/>
        <source>Gobo pictures</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="614"/>
        <source>Missing resources</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="615"/>
        <source>Some gobos are missing:

</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="481"/>
        <source>Some capabilities could not be created because of overlapping values.</source>
        <translation>Joitain toimintoja ei pystytty luomaan päällekäisten arvojen vuoksi.</translation>
    </message>
</context>
<context>
    <name>EditHead</name>
    <message>
        <location filename="edithead.ui" line="33"/>
        <source>Edit Head</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="edithead.ui" line="52"/>
        <source>Channel</source>
        <translation>Kanava</translation>
    </message>
    <message>
        <location filename="edithead.ui" line="57"/>
        <source>Name</source>
        <translation>Nimi</translation>
    </message>
</context>
<context>
    <name>EditMode</name>
    <message>
        <location filename="editmode.ui" line="33"/>
        <source>Edit Mode</source>
        <translation>Muokkaa tilaa</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="39"/>
        <source>Mode Name</source>
        <translation>Tilan nimi</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="53"/>
        <source>Channels</source>
        <translation>Kanavat</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="161"/>
        <source>Number</source>
        <translation>Numero</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="166"/>
        <source>Name</source>
        <translation>Nimi</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="79"/>
        <source>Add channel(s) to this mode</source>
        <translation>Lisää kanavia tähän tilaan</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="59"/>
        <source>Remove the selected channel</source>
        <translation>Poista valittu kanava</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="99"/>
        <source>Raise the selected channel</source>
        <translation>Nosta valittua kanavaa</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="119"/>
        <source>Lower the selected channel</source>
        <translation>Laske valittua kanavaa</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="171"/>
        <source>Acts On</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editmode.ui" line="193"/>
        <source>Heads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editmode.ui" line="206"/>
        <source>Head</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editmode.ui" line="214"/>
        <source>Compose a new head</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editmode.ui" line="234"/>
        <source>Remove the selected head</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editmode.ui" line="254"/>
        <source>Edit the channels that belong to the selected head</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editmode.ui" line="274"/>
        <source>Raise the selected head</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editmode.ui" line="294"/>
        <source>Lower the selected head</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editmode.ui" line="328"/>
        <source>Physical</source>
        <translation>Fyysiset ominaisuudet</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="338"/>
        <source>Use global settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editmode.ui" line="348"/>
        <source>Override global settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditPhysical</name>
    <message>
        <location filename="editphysical.ui" line="277"/>
        <source>Bulb</source>
        <translation>Polttimo</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="45"/>
        <location filename="editphysical.ui" line="283"/>
        <source>Type</source>
        <translation>Tyyppi</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="515"/>
        <source>Lumens</source>
        <translation>Lumenit</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="535"/>
        <source>Colour Temp (K)</source>
        <translation>Värilämpotila (K)</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="708"/>
        <source>Dimensions</source>
        <translation>Mitat</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="784"/>
        <source>Weight</source>
        <translation>Paino</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="714"/>
        <source>kg</source>
        <translation>kg</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="724"/>
        <source>Width</source>
        <translation>Leveys</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="734"/>
        <location filename="editphysical.ui" line="754"/>
        <location filename="editphysical.ui" line="774"/>
        <source>mm</source>
        <translation>mm</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="744"/>
        <source>Height</source>
        <translation>Korkeus</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="764"/>
        <source>Depth</source>
        <translation>Syvyys</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="39"/>
        <source>Head(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="630"/>
        <source>Lens</source>
        <translation>Linssi</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="636"/>
        <source>Name</source>
        <translation>Nimi</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="665"/>
        <source>Min Degrees</source>
        <translation>Min astetta</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="672"/>
        <source>Max Degrees</source>
        <translation>Max astetta</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="79"/>
        <source>Pan Max Degrees</source>
        <translation>Pan max astetta</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="96"/>
        <source>Tilt Max Degrees</source>
        <translation>Tilt max astetta</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="113"/>
        <source>Layout
(Columns x Rows)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="158"/>
        <source>Electrical</source>
        <translation>Elektroninen</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="164"/>
        <source>Power Consumption</source>
        <translation>Virrankulutus</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="174"/>
        <source>W</source>
        <translation>W</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="184"/>
        <source>DMX Connector</source>
        <translation>DMX-liitin</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="241"/>
        <source>Copy physical information to clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="258"/>
        <source>Paste physical information from clipboard</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FixtureEditor</name>
    <message>
        <location filename="fixtureeditor.ui" line="33"/>
        <source>Fixture</source>
        <translation>Valaisin</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="43"/>
        <source>General</source>
        <translation>Yleinen</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="55"/>
        <source>Manufacturer</source>
        <translation>Valmistaja</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="68"/>
        <source>The manufacturer name for this fixture (e.g. Martin)</source>
        <translation>Valaisimen valmistajan nimi (esim. Martin)</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="75"/>
        <source>Model</source>
        <translation>Malli</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="88"/>
        <source>The model name for this fixture (e.g. MAC250)</source>
        <translation>Valaisimen mallinimike (esim. MAC250)</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="95"/>
        <source>Type</source>
        <translation>Tyyppi</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="108"/>
        <source>The general type of this fixture</source>
        <translation>Valaisimen yleisluontoinen tyyppi</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="247"/>
        <source>Author</source>
        <translation>Tekijä</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="254"/>
        <source>The name of the author of this fixture definition</source>
        <oldsource>The author name of this fixture definition</oldsource>
        <translation>Valaisinmäärittelyn tekijän nimi</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="298"/>
        <location filename="fixtureeditor.ui" line="498"/>
        <source>Channels</source>
        <translation>Kanavat</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="320"/>
        <location filename="fixtureeditor.ui" line="493"/>
        <source>Name</source>
        <translation>Nimi</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="325"/>
        <source>Group</source>
        <translation>Ryhmä</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="333"/>
        <source>Add a channel</source>
        <translation>Lisää kanava</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="353"/>
        <source>Remove the selected channel</source>
        <translation>Poista valittu kanava</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="373"/>
        <source>Edit the selected channel</source>
        <translation>Muokkaa valittua kanavaa</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="400"/>
        <source>Copy the selected channel to the clipboard</source>
        <translation>Kopioi valittu kanava leikepöydälle</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="420"/>
        <source>Paste the channel in clipboard to this fixture</source>
        <translation>Liitä leikepöydällä oleva kanava tähän valaisimeen</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="453"/>
        <source>Open/close all channel items</source>
        <translation>Avaa/sulje kaikki kanavat</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="474"/>
        <source>Modes</source>
        <translation>Tilat</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="503"/>
        <source>Heads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="511"/>
        <source>Add a mode</source>
        <translation>Lisää tila</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="531"/>
        <source>Remove the selected mode</source>
        <translation>Poista valittu tila</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="551"/>
        <source>Edit the selected mode</source>
        <translation>Muokkaa valittua tilaa</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="578"/>
        <source>Create a copy of the selected mode</source>
        <translation>Luo valitusta tilasta kopio</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="611"/>
        <source>Open/close all mode items</source>
        <translation>Avaa/sulje kaikki tilat</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="632"/>
        <source>Aliases</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="650"/>
        <source>In mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="667"/>
        <source>Add a new alias</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="687"/>
        <source>with</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="694"/>
        <source>replace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="711"/>
        <location filename="fixtureeditor.ui" line="764"/>
        <source>Alias</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="716"/>
        <source>Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="721"/>
        <source>Base channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="726"/>
        <source>Override channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="744"/>
        <source>Remove the currently selected alias</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="275"/>
        <source>Physical</source>
        <translation type="unfinished">Fyysiset ominaisuudet</translation>
    </message>
</context>
<context>
    <name>QLCFixtureEditor</name>
    <message>
        <location filename="fixtureeditor.cpp" line="206"/>
        <source>Close</source>
        <translation>Sulje</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="207"/>
        <source>Do you want to save changes to fixture
&quot;%1&quot;
before closing?</source>
        <translation>Haluatko tallentaa muutokset valaisimeen
&quot;%1&quot;?</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="236"/>
        <location filename="fixtureeditor.cpp" line="246"/>
        <source>Missing important information</source>
        <translation>Tärkeitä tietoja puuttuu</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="237"/>
        <source>Missing manufacturer name.
Unable to save fixture.</source>
        <translation>Valmistajan nimi puuttuu.
Valaisinta ei voida tallentaa.</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="247"/>
        <source>Missing fixture model name.
Unable to save fixture.</source>
        <translation>Valaisimen malli puuttuu.
Valaisinta ei voida tallentaa.</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="277"/>
        <location filename="fixtureeditor.cpp" line="336"/>
        <source>Fixture saving failed</source>
        <translation>Valaisimen tallennus epäonnistui</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="278"/>
        <location filename="fixtureeditor.cpp" line="337"/>
        <source>Unable to save fixture definition:
%1</source>
        <oldsource>Unable to save fixture definition: </oldsource>
        <translation>Valaisinmäärittelyä ei voida tallentaa:
%1</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="293"/>
        <source>Save fixture definition</source>
        <translation>Tallenna valaisinmäärittely</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="370"/>
        <source>New Fixture</source>
        <translation>Uusi valaisin</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="447"/>
        <location filename="fixtureeditor.cpp" line="545"/>
        <source>Channel already exists</source>
        <translation>Kanava on jo olemassa</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="448"/>
        <location filename="fixtureeditor.cpp" line="546"/>
        <source>A channel by the name &quot;%1&quot; already exists!</source>
        <translation>Kanava nimeltä &quot;%1&quot; on jo olemassa!</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="455"/>
        <location filename="fixtureeditor.cpp" line="552"/>
        <source>Channel has no name</source>
        <translation>Kanavalla ei ole nimeä</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="456"/>
        <location filename="fixtureeditor.cpp" line="553"/>
        <source>You must give the channel a descriptive name!</source>
        <translation>Kanavalle täytyy antaa jokin kuvaava nimi!</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="493"/>
        <source>Are you sure you wish to remove channel: %1?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="824"/>
        <source>Are you sure you wish to remove mode: %1?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="665"/>
        <location filename="fixtureeditor.cpp" line="700"/>
        <location filename="fixtureeditor.cpp" line="937"/>
        <source>Edit</source>
        <translation>Muokkaa</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="666"/>
        <location filename="fixtureeditor.cpp" line="702"/>
        <source>Copy</source>
        <translation>Kopioi</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="667"/>
        <location filename="fixtureeditor.cpp" line="704"/>
        <source>Paste</source>
        <translation>Liitä</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="668"/>
        <location filename="fixtureeditor.cpp" line="706"/>
        <location filename="fixtureeditor.cpp" line="943"/>
        <source>Remove</source>
        <translation>Poista</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="679"/>
        <source>Channels</source>
        <translation>Kanavat</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="777"/>
        <location filename="fixtureeditor.cpp" line="786"/>
        <source>Unable to add mode</source>
        <translation>Tilaa ei voida lisätä</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="778"/>
        <source>Another mode by that name already exists</source>
        <translation>Toinen samanniminen tila on jo olemassa</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="787"/>
        <source>You must give a name to the mode</source>
        <translation>Tilalle on annettava nimi</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="823"/>
        <source>Remove Mode</source>
        <translation>Poista tila</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="883"/>
        <source>Rename new mode</source>
        <translation>Nimeä tila uudelleen</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="884"/>
        <source>Give a unique name for the mode</source>
        <translation>Anna tilalle yksilöllinen nimi</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="886"/>
        <source>Copy of %1</source>
        <translation>%1:n kopio</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="896"/>
        <source>Invalid name</source>
        <translation>Epäkelpo nimi</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="897"/>
        <source>Another mode by that name already exists.</source>
        <translation>Toinen samanniminen tila on jo olemassa.</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="940"/>
        <source>Clone</source>
        <translation>Kloonaa</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="948"/>
        <source>Modes</source>
        <translation>Tilat</translation>
    </message>
</context>
</TS>
